[cl-plus-ssl-cvs] CVS trivial-gray-streams

dlichteblau dlichteblau at common-lisp.net
Sat May 8 15:55:56 UTC 2010


Update of /project/cl-plus-ssl/cvsroot/trivial-gray-streams
In directory cl-net:/tmp/cvs-serv20519

Modified Files:
	mixin.lisp package.lisp 
Log Message:
Commit ABCL patch submitted by Mark Evenson

--- /project/cl-plus-ssl/cvsroot/trivial-gray-streams/mixin.lisp	2009/10/24 20:13:39	1.10
+++ /project/cl-plus-ssl/cvsroot/trivial-gray-streams/mixin.lisp	2010/05/08 15:55:55	1.11
@@ -29,6 +29,20 @@
   (declare (ignore newval))
   nil)
 
+#+abcl
+(progn
+  (defmethod gray-streams:stream-read-sequence 
+      ((s trivial-gray-stream-mixin) seq &optional start end)
+    (stream-read-sequence s seq (or start 0) (or end (length seq))))
+  
+  (defmethod gray-streams:stream-write-sequence 
+      ((s trivial-gray-stream-mixin) seq &optional start end)
+    (stream-write-sequence s seq (or start 0) (or end (length seq))))
+  
+  (defmethod gray-streams:stream-write-string 
+      ((stream xp::xp-structure) string &optional (start 0) (end (length string)))
+    (xp::write-string+ string stream start end)))
+
 #+allegro
 (progn
   (defmethod excl:stream-read-sequence
--- /project/cl-plus-ssl/cvsroot/trivial-gray-streams/package.lisp	2009/10/24 20:13:39	1.6
+++ /project/cl-plus-ssl/cvsroot/trivial-gray-streams/package.lisp	2010/05/08 15:55:56	1.7
@@ -2,6 +2,10 @@
 
 (in-package :cl-user)
 
+#+:abcl
+(eval-when (:compile-toplevel :load-toplevel :execute)
+  (require :gray-streams))
+
 #+cmu
 (eval-when (:compile-toplevel :load-toplevel :execute)
   (require :gray-streams))
@@ -40,8 +44,9 @@
 			  #+clisp :gray
 			  #+openmcl :ccl
 			  #+lispworks :stream
 			  #+ecl :gray
 			  #-(or sbcl allegro cmu clisp openmcl lispworks ecl) ...
 			  , at common-symbols)
 	    (:export #:trivial-gray-stream-mixin
 		     #:stream-read-sequence
@@ -40,8 +44,9 @@
 			  #+openmcl :ccl
 			  #+lispworks :stream
-			  #+ecl :gray
-			  #-(or sbcl allegro cmu clisp openmcl lispworks ecl) ...
+                          #+ecl :gray
+			  #+abcl :gray-streams
+			  #-(or sbcl allegro cmu clisp openmcl lispworks ecl abcl) ...
 			  , at common-symbols)
 	    (:export #:trivial-gray-stream-mixin





More information about the cl-plus-ssl-cvs mailing list